@@ -1,4 +1,4 @@
-""" Shared utilities: logging """
+"""Shared utilities: logging."""
 
 import fcntl
 import logging
@@ -11,44 +11,56 @@ import subprocess
 import sys
 import termios
 from dataclasses import dataclass, field
+from typing import Any, cast
 
 from .types import MonitorInfo, VersionInfo
 
 __all__ = [
     "DEBUG",
-    "get_logger",
-    "state",
     "apply_variables",
+    "get_logger",
     "merge",
     "run_interactive_program",
+    "state",
+    "init_logger",
+    "SharedState",
+    "prepare_for_quotes",
+    "apply_filter",
+    "CastBoolMixin",
+    "is_rotated",
 ]
 
+
 DEBUG = os.environ.get("DEBUG", False)
 
-HYPRLAND_INSTANCE_SIGNATURE = os.environ["HYPRLAND_INSTANCE_SIGNATURE"]
+HYPRLAND_INSTANCE_SIGNATURE = os.environ.get("HYPRLAND_INSTANCE_SIGNATURE", "NO_INSTANCE")
+
+MINIMUM_ADDR_LEN = 4
 
 try:
-    IPC_FOLDER = (
+    original_ipc_folder = (
         f'{os.environ["XDG_RUNTIME_DIR"]}/hypr/{HYPRLAND_INSTANCE_SIGNATURE}'
-        if os.path.exists(
-            f'{os.environ["XDG_RUNTIME_DIR"]}/hypr/{HYPRLAND_INSTANCE_SIGNATURE}'
-        )
-        else f"/tmp/hypr/{HYPRLAND_INSTANCE_SIGNATURE}"
+        if os.path.exists(f'{os.environ["XDG_RUNTIME_DIR"]}/hypr/{HYPRLAND_INSTANCE_SIGNATURE}')
+        else f"/tmp/hypr/{HYPRLAND_INSTANCE_SIGNATURE}"  # noqa: S108
     )
+
+    IPC_FOLDER = f"/tmp/.pypr-{HYPRLAND_INSTANCE_SIGNATURE}"  # noqa: S108
+    # make a link from short path to original path
+    if not os.path.exists(IPC_FOLDER):
+        os.symlink(original_ipc_folder, IPC_FOLDER)
+
 except KeyError:
-    print(
-        "This is a fatal error, assuming we are running documentation generation hence ignoring it"
-    )
-    IPC_FOLDER = "/fake"
+    print("This is a fatal error, assuming we are running documentation generation or testing in a sandbox, hence ignoring it")
+    IPC_FOLDER = "/"
 
 
-def set_terminal_size(descriptor, rows, cols):
-    "Set the terminal size"
+def set_terminal_size(descriptor: int, rows: int, cols: int) -> None:
+    """Set the terminal size."""
     fcntl.ioctl(descriptor, termios.TIOCSWINSZ, struct.pack("HHHH", rows, cols, 0, 0))
 
 
-def set_raw_mode(descriptor):
-    "Set a file descriptor in raw mode"
+def set_raw_mode(descriptor: int) -> None:
+    """Set a file descriptor in raw mode."""
     # Get the current terminal attributes
     attrs = termios.tcgetattr(descriptor)
     # Set the terminal to raw mode
@@ -57,8 +69,8 @@ def set_raw_mode(descriptor):
     termios.tcsetattr(descriptor, termios.TCSANOW, attrs)
 
 
-def run_interactive_program(command):
-    "Run an interactive program in a blocking way"
+def run_interactive_program(command: str) -> None:
+    """Run an interactive program in a blocking way."""
     # Create a pseudo-terminal
     master, slave = pty.openpty()
 
@@ -102,26 +114,25 @@ def run_interactive_program(command):
         termios.tcsetattr(sys.stdin, termios.TCSANOW, termios.tcgetattr(0))
 
 
-def merge(merged, obj2):
-    """
-    Merges the content of d2 into d1
+def merge(merged: dict[str, Any], obj2: dict[str, Any]) -> dict[str, Any]:
+    """Merge the content of d2 into d1.
+
+    Args:
+        merged (dict): Dictionary to merge into
+        obj2 (dict): Dictionary to merge from
+
+    Returns:
+        `merged` dictionary with the merged content
+
     Eg:
         merge({"a": {"b": 1}}, {"a": {"c": 2}}) == {"a": {"b": 1, "c": 2}}
 
-    Args:
-    - merged (dict): First dictionary to merge (will be updated).
-    - obj2 (dict): Second dictionary to merge
-
-    Returns:
-    - dict: Merged dictionary
     """
     for key, value in obj2.items():
         if key in merged and isinstance(merged[key], dict) and isinstance(value, dict):
             # If both values are dictionaries, recursively merge them
             merge(merged[key], value)
-        elif (
-            key in merged and isinstance(merged[key], list) and isinstance(value, list)
-        ):
+        elif key in merged and isinstance(merged[key], list) and isinstance(value, list):
             # If both values are lists, concatenate them
             merged[key] += value
         else:
@@ -131,24 +142,21 @@ def merge(merged, obj2):
 
 
 class LogObjects:
-    """Reusable objects for loggers"""
+    """Reusable objects for loggers."""
 
     handlers: list[logging.Handler] = []
 
 
-def init_logger(filename=None, force_debug=False):
-    """initializes the logging system"""
+def init_logger(filename: str | None = None, force_debug: bool = False) -> None:
+    """Initialize the logging system."""
     global DEBUG
     if force_debug:
         DEBUG = True
 
     class ScreenLogFormatter(logging.Formatter):
-        "A custom formatter, adding colors"
-        LOG_FORMAT = (
-            r"%(name)25s - %(message)s // %(filename)s:%(lineno)d"
-            if DEBUG
-            else r"%(message)s"
-        )
+        """A custom formatter, adding colors."""
+
+        LOG_FORMAT = r"%(name)25s - %(message)s // %(filename)s:%(lineno)d" if DEBUG else r"%(message)s"
         RESET_ANSI = "\x1b[0m"
 
         FORMATTERS = {
@@ -159,25 +167,21 @@ def init_logger(filename=None, force_debug=False):
             logging.CRITICAL: logging.Formatter("\x1b[31;1m" + LOG_FORMAT + RESET_ANSI),
         }
 
-        def format(self, record):
+        def format(self, record: logging.LogRecord) -> str:
             return self.FORMATTERS[record.levelno].format(record)
 
     logging.basicConfig()
     if filename:
         file_handler = logging.FileHandler(filename)
-        file_handler.setFormatter(
-            logging.Formatter(
-                fmt=r"%(asctime)s [%(levelname)s] %(name)s :: %(message)s :: %(filename)s:%(lineno)d"
-            )
-        )
+        file_handler.setFormatter(logging.Formatter(fmt=r"%(asctime)s [%(levelname)s] %(name)s :: %(message)s :: %(filename)s:%(lineno)d"))
         LogObjects.handlers.append(file_handler)
     stream_handler = logging.StreamHandler()
     stream_handler.setFormatter(ScreenLogFormatter())
     LogObjects.handlers.append(stream_handler)
 
 
-def get_logger(name="pypr", level=None) -> logging.Logger:
-    """Returns a named logger
+def get_logger(name: str = "pypr", level: int | None = None) -> logging.Logger:
+    """Return a named logger.
 
     Args:
         name (str): logger's name
@@ -197,7 +201,8 @@ def get_logger(name="pypr", level=None) -> logging.Logger:
 
 @dataclass
 class SharedState:
-    "Stores commonly requested properties"
+    """Stores commonly requested properties."""
+
     active_workspace: str = ""  # workspace name
     active_monitor: str = ""  # monitor name
     active_window: str = ""  # window address
@@ -206,7 +211,7 @@ class SharedState:
     hyprland_version: VersionInfo = field(default_factory=VersionInfo)
 
 
-state = SharedState()
+state: SharedState = SharedState()
 """
 Exposes most-commonly accessed attributes to avoid specific IPC requests
 - `active_monitor` monitor's name
@@ -215,29 +220,32 @@ Exposes most-commonly accessed attributes to avoid specific IPC requests
 """
 
 
-def prepare_for_quotes(text: str):
-    "Escapes double quotes in text"
+def prepare_for_quotes(text: str) -> str:
+    """Escapes double quotes in text."""
     return text.replace('"', '\\"')
 
 
-def apply_variables(template: str, variables: dict[str, str]):
-    """Replace [var_name] with content from supplied variables
+def apply_variables(template: str, variables: dict[str, str]) -> str:
+    """Replace [var_name] with content from supplied variables.
+
     Args:
         template: the string template
         variables: a dict containing the variables to replace
     """
     pattern = r"\[([^\[\]]+)\]"
 
-    def replace(match):
+    def replace(match: re.Match[str]) -> str:
         var_name = match.group(1)
         return variables.get(var_name, match.group(0))
 
     return re.sub(pattern, replace, template)
 
 
-def apply_filter(text, filt_cmd: str):
-    """Apply filters to text
-    Currently supports only "s" command fom vim/ed"""
+def apply_filter(text: str, filt_cmd: str) -> str:
+    """Apply filters to text.
+
+    Currently supports only "s" command fom vim/ed
+    """
     if not filt_cmd:
         return text
     if filt_cmd[0] == "s":  # vi-like substitute
@@ -247,21 +255,19 @@ def apply_filter(text, filt_cmd: str):
 
 
 class CastBoolMixin:
-    "Adds `cast_bool` method"
+    """Adds `cast_bool` method."""
 
     log: logging.Logger
 
-    def cast_bool(self, value, default_value=False):
-        "recovers wrong typing on boolean values"
+    def cast_bool(self, value: str | bool | None, default_value: bool = False) -> bool:
+        """Recovers wrong typing on boolean values."""
         if isinstance(value, str):
             lv = value.lower().strip()
-            r = lv not in ("false", "no", "off")
-            self.log.warning(
-                "Invalid value for boolean option: %s, considering it %s", value, r
-            )
-        return default_value if value is None else value
+            r = lv not in {"false", "no", "off"}
+            self.log.warning("Invalid value for boolean option: %s, considering it %s", value, r)
+        return default_value if value is None else cast(bool, value)
 
 
 def is_rotated(monitor: MonitorInfo) -> bool:
-    "Returns True if the monitor is rotated"
-    return monitor["transform"] in (1, 3, 5, 7)
+    """Return True if the monitor is rotated."""
+    return monitor["transform"] in {1, 3, 5, 7}
