@@ -1,6 +1,7 @@
-" Plugin template "
+"""Plugin template."""
+
 from .interface import Plugin
 
 
 class Extension(Plugin):
-    "Sample plugin template"
+    """Sample plugin template."""
