@@ -1,5 +1,5 @@
-"""
-Implements a "Centered" layout:
+"""Implements a "Centered" layout.
+
 - windows are normally tiled but one
 - the active window is floating and centered
 - you can cycle the active window, keeping the same layout type
@@ -10,21 +10,20 @@ from collections import defaultdict
 from typing import Any, cast
 
 from ..common import CastBoolMixin, state
+from ..types import ClientInfo
 from .interface import Plugin
 
 
 class Extension(CastBoolMixin, Plugin):
-    "Manages a layout with one centered window on top of others"
+    """Manages a layout with one centered window on top of others."""
 
-    workspace_info: dict[str, dict[str, Any]] = defaultdict(
-        lambda: {"enabled": False, "addr": ""}
-    )
+    workspace_info: dict[str, dict[str, Any]] = defaultdict(lambda: {"enabled": False, "addr": ""})
     last_index = 0
 
     # Events
 
-    async def event_openwindow(self, windescr):
-        "Re-set focus to main if a window is opened"
+    async def event_openwindow(self, windescr: str) -> None:
+        """Re-set focus to main if a window is opened."""
         if not self.enabled:
             return
         win_addr = "0x" + windescr.split(",", 1)[0]
@@ -34,25 +33,20 @@ class Extension(CastBoolMixin, Plugin):
                 self.last_index = i
                 break
 
-    async def event_activewindowv2(self, _):
-        "keep track of focused client"
-        if (
-            self.cast_bool(self.config.get("captive_focus"))
-            and self.enabled
-            and state.active_window != self.main_window_addr
-            and len(
-                [
-                    c
-                    for c in await self.get_clients()
-                    if c["address"] == state.active_window
-                ]
-            )
-            > 0
-        ):
-            await self.hyprctl(f"focuswindow address:{self.main_window_addr}")
+    async def event_activewindowv2(self, _: str) -> None:
+        """Keep track of focused client."""
+        captive = self.cast_bool(self.config.get("captive_focus"))
+        is_not_active = state.active_window != self.main_window_addr
+        if captive and self.enabled and is_not_active:
+            try:
+                next(c for c in await self.get_clients() if c["address"] == state.active_window)
+            except StopIteration:
+                pass
+            else:
+                await self.hyprctl(f"focuswindow address:{self.main_window_addr}")
 
-    async def event_closewindow(self, addr):
-        "Disable when the main window is closed"
+    async def event_closewindow(self, addr: str) -> None:
+        """Disable when the main window is closed."""
         addr = "0x" + addr
         clients = [c for c in await self.get_clients() if c["address"] != addr]
         if self.enabled and await self._sanity_check(clients):
@@ -63,8 +57,8 @@ class Extension(CastBoolMixin, Plugin):
 
     # Command
 
-    async def run_layout_center(self, what):
-        "<toggle|next|prev> turn on/off or change the active window"
+    async def run_layout_center(self, what: str) -> None:
+        """<toggle|next|prev> turn on/off or change the active window."""
         if what == "toggle":
             await self._run_toggle()
         elif what == "next":
@@ -80,16 +74,14 @@ class Extension(CastBoolMixin, Plugin):
 
     # Utils
 
-    async def get_clients(self):  # pylint: disable=arguments-differ
-        "Return the client list in the currently active workspace"
-        clients = await super().get_clients(
-            mapped=True, workspace=state.active_workspace
-        )
+    async def get_clients(self, *_) -> list[ClientInfo]:  # pylint: disable=arguments-differ
+        """Return the client list in the currently active workspace."""
+        clients = await super().get_clients(mapped=True, workspace=state.active_workspace)
         clients.sort(key=lambda c: c["address"])
         return clients
 
-    async def unprepare_window(self, clients=None):
-        "Set the window as normal"
+    async def unprepare_window(self, clients: list[ClientInfo] | None = None) -> None:
+        """Set the window as normal."""
         if not clients:
             clients = await self.get_clients()
         addr = self.main_window_addr
@@ -97,8 +89,8 @@ class Extension(CastBoolMixin, Plugin):
             if cli["address"] == addr and cli["floating"]:
                 await self.hyprctl(f"togglefloating address:{addr}")
 
-    async def prepare_window(self, clients=None):
-        "Set the window as centered"
+    async def prepare_window(self, clients: list[ClientInfo] | None = None) -> None:
+        """Set the window as centered."""
         if not clients:
             clients = await self.get_clients()
         addr = self.main_window_addr
@@ -110,7 +102,7 @@ class Extension(CastBoolMixin, Plugin):
         x, y = self.offset
         margin = self.margin
         scale = 1
-        for monitor in cast(list[dict[str, Any]], await self.hyprctlJSON("monitors")):
+        for monitor in cast(list[dict[str, Any]], await self.hyprctl_json("monitors")):
             scale = monitor["scale"]
             if monitor["focused"]:
                 width = monitor["width"] - (2 * margin)
@@ -118,27 +110,23 @@ class Extension(CastBoolMixin, Plugin):
                 x += monitor["x"] + margin
                 y += monitor["y"] + margin
                 break
-        await self.hyprctl(
-            f"resizewindowpixel exact {int(width/scale)} {int(height/scale)},address:{addr}"
-        )
-        await self.hyprctl(
-            f"movewindowpixel exact {int(x/scale)} {int(y/scale)},address:{addr}"
-        )
+        await self.hyprctl(f"resizewindowpixel exact {int(width / scale)} {int(height / scale)},address:{addr}")
+        await self.hyprctl(f"movewindowpixel exact {int(x / scale)} {int(y / scale)},address:{addr}")
 
     # Subcommands
 
-    async def _sanity_check(self, clients=None):
-        "Auto-disable if needed & return enabled status"
+    async def _sanity_check(self, clients: list[ClientInfo] | None = None) -> bool:
+        """Auto-disable if needed & return enabled status."""
         clients = clients or await self.get_clients()
-        if len(clients) < 2:
+        if len(clients) < 2:  # noqa: PLR2004
             # If < 2 clients, disable the layout & stop
             self.log.info("disabling (clients starvation)")
             await self.unprepare_window()
             self.enabled = False
         return self.enabled
 
-    async def _run_changefocus(self, direction, default_override=None):
-        "Change the focus in the given direction (-1 or 1)"
+    async def _run_changefocus(self, direction: int, default_override: str | None = None) -> None:
+        """Change the focus in the given direction (-1 or 1)."""
         if self.enabled:
             clients = await self.get_clients()
             if await self._sanity_check(clients):
@@ -158,13 +146,13 @@ class Extension(CastBoolMixin, Plugin):
                 await self.hyprctl(f"focuswindow address:{self.main_window_addr}")
                 self.last_index = index
                 await self.prepare_window(clients)
-        else:
+        elif default_override:
             command = self.config.get(default_override)
             if command:
                 await self.hyprctl(command)
 
-    async def _run_toggle(self):
-        "toggle the center layout"
+    async def _run_toggle(self) -> None:
+        """Toggle the center layout."""
         disabled = not self.enabled
         if disabled:
             self.main_window_addr = state.active_window
@@ -177,45 +165,38 @@ class Extension(CastBoolMixin, Plugin):
     # Properties
 
     @property
-    def offset(self):
-        "Returns the centered window offset"
-        offset = self.config.get("offset", [0, 0])
+    def offset(self) -> tuple[int, int]:
+        """Returns the centered window offset."""
+        offset = self.config.get("offset", (0, 0))
         if isinstance(offset, str):
             x, y = (int(i) for i in self.config["offset"].split() if i.strip())
-            return [x, y]
-        return offset
+            return (x, y)
+        return cast(tuple[int, int], offset)
 
     @property
-    def margin(self):
-        "Returns the margin of the centered window"
-        return self.config.get("margin", 60)
+    def margin(self) -> int:
+        """Returns the margin of the centered window."""
+        return cast(int, self.config.get("margin", 60))
 
     # enabled
-    def get_enabled(self):
-        "Is center layout enabled on the active workspace ?"
-        return self.workspace_info[state.active_workspace]["enabled"]
+    @property
+    def enabled(self) -> bool:
+        """Is center layout enabled on the active workspace ?."""
+        return cast(bool, self.workspace_info[state.active_workspace]["enabled"])
 
-    def set_enabled(self, value):
-        "set if center layout enabled on the active workspace"
+    @enabled.setter
+    def enabled(self, value: bool) -> None:
+        """Set if center layout enabled on the active workspace."""
         self.workspace_info[state.active_workspace]["enabled"] = value
 
-    enabled = property(
-        get_enabled, set_enabled, doc="centered layout enabled on this workspace"
-    )
-    del get_enabled, set_enabled
-
     # main_window_addr
-    def get_main_window_addr(self):
-        "get active workspace's centered window address"
-        return self.workspace_info[state.active_workspace]["addr"]
 
-    def set_main_window_addr(self, value):
-        "set active workspace's centered window address"
+    @property
+    def main_window_addr(self) -> str:
+        """Get active workspace's centered window address."""
+        return cast(str, self.workspace_info[state.active_workspace]["addr"])
+
+    @main_window_addr.setter
+    def main_window_addr(self, value: str) -> None:
+        """Set active workspace's centered window address."""
         self.workspace_info[state.active_workspace]["addr"] = value
-
-    main_window_addr = property(
-        get_main_window_addr,
-        set_main_window_addr,
-        doc="active workspace's centered window address",
-    )
-    del get_main_window_addr, set_main_window_addr
