@@ -1,5 +1,4 @@
-""" toggle_special allows having an "expose" like selection of windows in a special group
-"""
+"""toggle_special allows having an "expose" like selection of windows in a special group."""
 
 from typing import cast
 
@@ -8,9 +7,11 @@ from .interface import Plugin
 
 
 class Extension(Plugin):  # pylint: disable=missing-class-docstring
-    async def run_toggle_special(self, special_workspace="minimized"):
-        """[name] Toggles switching the focused window to the special workspace "name" (default: minimized)"""
-        aw = cast(dict, await self.hyprctlJSON("activewindow"))
+    """Toggle switching the focused window to a special workspace."""
+
+    async def run_toggle_special(self, special_workspace: str = "minimized") -> None:
+        """[name] Toggles switching the focused window to the special workspace "name" (default: minimized)."""
+        aw = cast(dict, await self.hyprctl_json("activewindow"))
         wid = aw["workspace"]["id"]
         assert isinstance(wid, int)
         if wid < 1:  # special workspace
@@ -22,6 +23,4 @@ class Extension(Plugin):  # pylint: disable=missing-class-docstring
                 ]
             )
         else:
-            await self.hyprctl(
-                f"movetoworkspacesilent special:{special_workspace},address:{aw['address']}"
-            )
+            await self.hyprctl(f"movetoworkspacesilent special:{special_workspace},address:{aw['address']}")
