@@ -1,22 +1,24 @@
-" Common types from Hyprland API"
+"""Common types from Hyprland API."""
 
 from dataclasses import dataclass
 from typing import TypedDict
 
 
 class WorkspaceDf(TypedDict):
-    "Workspace definition"
+    """Workspace definition."""
+
     id: int
     name: str
 
 
 class ClientInfo(TypedDict):
-    "Client information as returned by Hyprland"
+    """Client information as returned by Hyprland."""
+
     address: str
     mapped: bool
     hidden: bool
-    at: list[int]
-    size: list[int]
+    at: tuple[int, int]
+    size: tuple[int, int]
     workspace: WorkspaceDf
     floating: bool
     monitor: int
@@ -36,7 +38,8 @@ class ClientInfo(TypedDict):
 
 
 class MonitorInfo(TypedDict):
-    "Monitor information as returned by Hyprland"
+    """Monitor information as returned by Hyprland."""
+
     id: int
     name: str
     description: str
@@ -64,11 +67,12 @@ class MonitorInfo(TypedDict):
 
 @dataclass(order=True)
 class VersionInfo:
-    "Stores version information"
-    major: int = 0  # noqa: F841
-    minor: int = 0  # noqa: F841
-    micro: int = 0  # noqa: F841
+    """Stores version information."""
+
+    major: int = 0
+    minor: int = 0
+    micro: int = 0
 
 
-class PyprError(Exception):
-    """Used for errors which already triggered logging"""
+class PyprError(BaseException):
+    """Used for errors which already triggered logging."""
